OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Міграція триває. Будь ласка, зачекайте доки процес міграції завершиться",
    "Migration started …" : "Міграцію розпочато ...",
    "Saved" : "Збережено",
    "Not saved" : "Не збережено",
    "Sending…" : "Відправка...",
    "Email sent" : "Лист надіслано",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Виникла помилка. Будь ласка вивантажте PEM сертифікат в ASCII-кодуванні.",
    "Valid until {date}" : "Дійсно до {date}",
    "Delete" : "Видалити",
    "Local" : "Локально",
    "Private" : "Закритий",
    "Only visible to local users" : "Видимий тільки для локальних користувачів",
    "Only visible to you" : "Видимий тільки вам",
    "Contacts" : "Контакти",
    "Visible to local users and to trusted servers" : "Видимий тільки локальним користувачам і довіреним серверам",
    "Public" : "Відкритий",
    "Will be synced to a global and public address book" : "Буде синхронізовано з глобальною та відкритою адресною книгою",
    "Verify" : "Перевірити",
    "Verifying …" : "Перевірка ...",
    "Unable to change password" : "Неможливо змінити пароль",
    "Very weak password" : "Дуже слабкий пароль",
    "Weak password" : "Слабкий пароль",
    "So-so password" : "Такий собі пароль",
    "Good password" : "Добрий пароль",
    "Strong password" : "Надійний пароль",
    "An error occurred while changing your language. Please reload the page and try again." : "Виникла помилка при зміні мови. Перезавантажте сторінку та повторіть спробу.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Виникла помилка при зміні локалі. Перезавантажте сторінку та повторіть спробу.",
    "Select a profile picture" : "Обрати зображення облікового запису",
    "Week starts on {fdow}" : "Тиждень починається в {fdow}",
    "Groups" : "Групи",
    "Group list is empty" : "Список груп порожній",
    "Unable to retrieve the group list" : "Неможливо отримати список груп",
    "{actor} added you to group {group}" : "{actor} додав вас до групи {group}",
    "You added {user} to group {group}" : "Ви додали {user} до групи {group}",
    "{actor} added {user} to group {group}" : "{actor} додав {user} до групи {group}",
    "An administrator added you to group {group}" : "Адміністратор додав вас до групи {group}",
    "An administrator added {user} to group {group}" : "Адміністратор додав {user} до групи {group}",
    "{actor} removed you from group {group}" : "{actor} вилучив вас із групи {group}",
    "You removed {user} from group {group}" : "Ви вилучили {user} з групи {group}",
    "{actor} removed {user} from group {group}" : "{actor} вилучив {user} з групи {group}",
    "An administrator removed you from group {group}" : "Адміністратор вилучив вас з групи {group}",
    "An administrator removed {user} from group {group}" : "Адміністратор вилучив {user} з групи {group}",
    "Your <strong>group memberships</strong> were modified" : "Парамеири вашої <strong>участі в групі</strong> оновлено",
    "{actor} changed your password" : "{actor} змінив ваш пароль",
    "You changed your password" : "Ви змінили свій пароль",
    "Your password was reset by an administrator" : "Ваш пароль був скинутий адміністратором",
    "{actor} changed your email address" : "{actor} змінив вашу email адресу",
    "You changed your email address" : "Ви змінили вашу email адресу",
    "Your email address was changed by an administrator" : "Ваша email адреса змінена адміністратором",
    "Security" : "Безпека",
    "You successfully logged in using two-factor authentication (%1$s)" : "Ви успішно увійшли, використовуючи двофакторну аутентифікацію (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Помилка спроби входу в систему, використовуючи двофакторну аутентифікацію (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ваш <strong>пароль</strong> чи <strong>електронна пошта</strong> були змінені",
    "Couldn't remove app." : "Неможливо вилучити застосунок.",
    "Couldn't update app." : "Не вдалося оновити застосунок.",
    "Wrong password" : "Неправильний пароль",
    "No user supplied" : "Користувача не вказано",
    "Authentication error" : "Помилка автентифікації",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Будь ласка, введіть пароль відновлення адміністратора; інакше всі дані користувача будуть втрачені.",
    "Wrong admin recovery password. Please check the password and try again." : "Невірний пароль відновлення адміністратора.  Будь ласка, перевірте пароль та спробуйте ще раз.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Бекенд не підтримує зміну пароля, але ключ шифрування користувача був оновлений.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "встановлення та оновлення додатків через магазин додатків або Об’єднання хмарних сховищ",
    "Federated Cloud Sharing" : "Об’єднання хмарних сховищ",
    "Invalid SMTP password." : "Недійсний пароль SMTP.",
    "Email setting test" : "Тестування параметрів електронної пошти",
    "Well done, %s!" : "Молодець, %s!",
    "If you received this email, the email configuration seems to be correct." : "Якщо ви отримали цей електронний лист, то налаштування електронної пошти правильні.",
    "Email could not be sent. Check your mail server log" : "Не вдалося надіслати електронну пошту. Перевірте журнал поштового сервера",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Під час надсилання email сталася помилка. Будь ласка перевірте налаштування. (Помилка: %s)",
    "You need to set your user email before being able to send test emails." : "Перед надсиланням тестових листів ви повинні вказати свою email адресу.",
    "Invalid mail address" : "Неправильна email адреса",
    "Settings saved" : "Налаштування збережено",
    "Unable to change full name" : "Неможливо змінити повне ім'я",
    "Unable to change email address" : "Неможливо змінити електронну адресу",
    "%1$s changed your password on %2$s." : "%1$s змінив ваш пароль для сервера %2$s.",
    "Your password on %s was changed." : "Ваш пароль на сервері %s був змінений.",
    "Your password on %s was reset by an administrator." : "Ваш пароль на сервері %s був скинутий адміністратором",
    "Password for %1$s changed on %2$s" : "Пароль %1$s змінений на сервері %2$s",
    "Password changed for %s" : "Пароль змінено для %s",
    "If you did not request this, please contact an administrator." : "Якщо ви цього не просили, зв'яжіться з адміністратором.",
    "Your email address on %s was changed." : "Ваша електронна адреса на сервері %s була змінена.",
    "Your email address on %s was changed by an administrator." : "Ваша електронна адреса на сервері %s була змінена адміністратором.",
    "Email address for %1$s changed on %2$s" : "Електронна адреса %1$s змінена на %2$s",
    "Email address changed for %s" : "Адресу електронної пошти змінено для %s",
    "The new email address is %s" : "Нова адреса електронної пошти: %s",
    "Your %s account was created" : "Ваш обліковий запис %s створено",
    "Welcome aboard" : "Ласкаво просимо на борт",
    "Welcome aboard %s" : "Ласкаво просимо на борт, %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Ласкаво просимо до вашого облікового запису, %s, ви можете додавати, захищати та ділитися своїми даними.",
    "Your username is: %s" : "Ваше ім'я користувача: %s",
    "Set your password" : "Встановіть свій пароль",
    "Go to %s" : "Перейти до %s",
    "Install Client" : "Встановити Клієнт",
    "Unlimited" : "Необмежено",
    "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Двофакторна автентифікація може застосовуватися для всіх \t користувачів і конкретних груп. Якщо вони не мають налаштованого двофакторного провайдера для входу, вони не зможуть увійти в систему.",
    "Enforce two-factor authentication" : "Примусова двофакторна аутентифікація",
    "Limit to groups" : "Обмежити групами",
    "Save changes" : "Зберегти зміни",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Офіційні додатки розробляються спільнотою та в межах спільноти. Вони пропонують основну функціональність і готові до використання в продакшні.",
    "Official" : "Офіційні",
    "Update to {version}" : "Оновити до {version}",
    "Remove" : "Видалити",
    "Disable" : "Вимкнути",
    "All" : "Всі",
    "Limit app usage to groups" : "Обмежити використання додатку заданими групами",
    "No results" : "Немає результатів",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ця програма не може бути встановлено, так як наступні залежності не будуть виконані:",
    "View in store" : "Переглянути в магазині додатків",
    "Visit website" : "Відвідати веб-сайт",
    "Report a bug" : "Повідомити про помилку",
    "User documentation" : "Користувацька документація",
    "Admin documentation" : "Документація адміністратора",
    "Developer documentation" : "Документація для розробників",
    "No apps found for your version" : "Немає додатків для вашої версії",
    "Disable all" : "Вимкнути все",
    "Enable all" : "Увімкнути все",
    "Download and enable" : "Завантажити та увімкнути",
    "Enable" : "Увімкнути",
    "The app will be downloaded from the app store" : "Додаток буде завантажено з магазину додатків",
    "Device settings" : "Налаштування пристрою",
    "Allow filesystem access" : "Дозволити доступ до файлової системи",
    "Revoke" : "Відкликати",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome для Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Додаток Nextcloud для iOS",
    "Nextcloud Android app" : "Додаток Nextcloud для Android",
    "Nextcloud Talk for iOS" : "Додаток Talk для iOS",
    "Nextcloud Talk for Android" : "Додаток Talk для Android",
    "Sync client - {os}" : "Клієнт синхронізації - {os}",
    "This session" : "Цей сеанс",
    "Device" : "Пристрій",
    "Last activity" : "Остання активність",
    "Devices & sessions" : "Пристрої та сеанси",
    "Web, desktop and mobile clients currently logged in to your account." : "Веб, настільні та мобільні клієнти в даний час авторизовані у вашому обліковому записі",
    "Error while creating device token" : "Помилка під час створення токена пристрою",
    "Error while deleting the token" : "Помилка при видаленні токену",
    "App name" : "Ім'я додатку",
    "Create new app password" : "Створіть новий пароль додатка",
    "Username" : "Ім'я користувача",
    "Password" : "Пароль",
    "Done" : "Готово",
    "Copied!" : "Скопійовано!",
    "Copy" : "Копіювати",
    "You do not have permissions to see the details of this user" : "Ви не маєте прав для перегляду деталей про цього користувача",
    "The backend does not support changing the display name" : "Бекенд не підтримує зміну відображуваного імені",
    "New password" : "Новий пароль",
    "Add user in group" : "Додати користувача в групу",
    "Set user as admin for" : "Встановити користувача як адміністратора для",
    "Select user quota" : "Виберіть квоту користувача",
    "No language set" : "Мова не встановлена",
    "Never" : "Ніколи",
    "Delete user" : "Видалити користувача",
    "Disable user" : "Вимкнути користувача",
    "Enable user" : "Увімкнути користувача",
    "Resend welcome email" : "Відправити запрошення ще раз",
    "{size} used" : "{size} використано",
    "Welcome mail sent!" : "Запрошення надіслано!",
    "Display name" : "Ім'я для відображення",
    "Email" : "E-mail",
    "Group admin for" : "Адміністратор групи для",
    "Quota" : "Квота",
    "Language" : "Мова",
    "Storage location" : "Місце розташування сховища",
    "Last login" : "Останній вхід",
    "Default language" : "Мова за замовчуванням",
    "Add a new user" : "Додати нового користувача",
    "No users in here" : "Немає користувачів",
    "Default quota" : "Квота за замовчуванням",
    "Common languages" : "Основні мови",
    "All languages" : "Всі мови",
    "Password change is disabled because the master key is disabled" : "Зміну пароля вимкнено, оскільки майстер-ключ відключений",
    "Your apps" : "Ваші додатки",
    "Active apps" : "Активні додатки",
    "Disabled apps" : "Відключені додатки",
    "Updates" : "Оновлення",
    "App bundles" : "Набори програм",
    "{license}-licensed" : "Ліцензія: {license}",
    "New user" : "Новий користувач",
    "Default quota:" : "Квота за замовчуванням:",
    "Select default quota" : "Виберіть квоту за замовчуванням",
    "Show Languages" : "Показати мови",
    "Show last login" : "Показати останній вхід",
    "Show user backend" : "Показати користувача",
    "Show storage path" : "Показати шлях до сховища",
    "Remove group" : "Видалити групу",
    "Admins" : "Адміністратори",
    "Disabled users" : "Вимкнені користувачі",
    "Everyone" : "Всі",
    "Add group" : "Додати групу",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Ви збираєтеся видалити групу {group}. Користувачі групи НЕ будуть видалені.",
    "Please confirm the group removal " : "Будь ласка, підтвердьте видалення групи",
    "An error occured during the request. Unable to proceed." : "Під час запиту сталася помилка. Не вдається продовжити.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Додаток активовано, але його потрібно оновити. Ви будете перенаправлені на сторінку оновлення через 5 секунд.",
    "App update" : "Оновлення додатку",
    "Error: This app can not be enabled because it makes the server unstable" : "Помилка: цей додаток неможливо ввімкнути, оскільки він робить сервер нестабільним",
    "SSL Root Certificates" : "Кореневі сертифікати SSL",
    "Common Name" : "Ім'я (CN)",
    "Valid until" : "Дійсно до",
    "Issued By" : "Випущено",
    "Valid until %s" : "Дійсно до %s",
    "Import root certificate" : "Імпортувати кореневий сертифікат",
    "Administrator documentation" : "Документація адміністратора",
    "Documentation" : "Документація",
    "Forum" : "Форум",
    "None" : "Відсутній",
    "Login" : "Логін",
    "Plain" : "Звичайний",
    "NT LAN Manager" : "Менеджер NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Сервер електронної пошти",
    "Open documentation" : "Відкрити документацію",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Важливо налаштувати цей сервер, для надсилання електронних листів, наприклад, для скидання пароля та сповіщень.",
    "Send mode" : "Режим надсилання",
    "Encryption" : "Шифрування",
    "From address" : "Адреса відправника",
    "mail" : "пошта",
    "Authentication method" : "Спосіб аутентифікації",
    "Authentication required" : "Потрібна аутентифікація",
    "Server address" : "Адреса сервера",
    "Port" : "Порт",
    "Credentials" : "Облікові дані",
    "SMTP Username" : "Ім'я користувача SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Test email settings" : "Тестувати налаштування ел. пошти",
    "Send email" : "Надіслати листа",
    "Security & setup warnings" : "Попередження безпеки та налаштування",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Для безпеки та продуктивності вашого сервера важливо, щоб все було налаштовано правильно. Щоб допомогти вам, ми робимо деякі автоматичні перевірки. Будь ласка, перегляньте пов'язану документацію для отримання додаткової інформації.",
    "All checks passed." : "Всі перевірки пройдено.",
    "There are some errors regarding your setup." : "У ваших налаштуваннях є деякі помилки.",
    "There are some warnings regarding your setup." : "У ваших налаштуваннях є деякі застереження.",
    "Checking for system and security issues." : "Перевірка проблем системи та безпеки.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Перевірте безпеку вашого Nextcloud <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">скануваннм безпеки ↗</a>.",
    "Version" : "Версія",
    "Two-Factor Authentication" : "Двофакторна аутентифікація",
    "Server-side encryption" : "Шифрування на сервері",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Шифрування на стороні сервера дозволяє шифрувати файли, завантажені на цей сервер. Це має свою ціну, таку як зниження продуктивності, тому ввімкніть його лише за потреби.",
    "Enable server-side encryption" : "Увімкнути шифрування на сервері",
    "Please read carefully before activating server-side encryption: " : "Будьте обережні під час активування шифрування на сервері:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Після активації шифрування, всі файли завантажені на сервер з цього моменту, будуть зашифровані на сервері. Відключити шифрування пізніше можна буде тільки якщо активний модуль шифрування підтримує цю функцію, і при виконанні певних умов (наприклад, налаштований ключ відновлення).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Саме по собі шифрування не гарантує безпеку системи. Будь ласка, перегляньте документацію, щоб отримати додаткову інформацію про те, як працює додаток для шифрування, та про приклади його використання.",
    "Be aware that encryption always increases the file size." : "Майте на увазі, що шифрування завжди збільшує розмір файлів.",
    "Enable encryption" : "Увімкнути шифрування",
    "Select default encryption module:" : "Обрати модуль шифрування за замовчуванням:",
    "Start migration" : "Розпочати міграцію",
    "Background jobs" : "Фонові завдання",
    "Last job ran %s." : "Останнє завдання запускалось %s.",
    "Execute one task with each page loaded" : "Виконати одне завдання для кожної завантаженої сторінки ",
    "Sharing" : "Спільний доступ",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Як адміністратор ви можете точно налаштувати поведінку спільного використання. Будь ласка, перегляньте документацію для отримання додаткової інформації.",
    "Allow apps to use the Share API" : "Дозволити програмам використовувати API спільного доступу",
    "Allow users to share via link" : "Дозволити користувачам ділитися через посилання",
    "Allow public uploads" : "Дозволити публічне завантаження",
    "Always ask for a password" : "Завжди запитувати пароль",
    "Enforce password protection" : "Захист паролем обов'язковий",
    "Set default expiration date" : "Встановити термін дії за замовчуванням",
    "Expire after " : "Скінчиться через",
    "days" : "днів",
    "Enforce expiration date" : "Термін дії обов'язковий",
    "Allow resharing" : "Дозволити перевідкривати спільний доступ",
    "Allow sharing with groups" : "Дозволити спільне використання групами",
    "Restrict users to only share with users in their groups" : "Дозволити користувачам відкривати спільний доступ лише для користувачів з їхньої групи",
    "Exclude groups from sharing" : "Виключити групи зі спільного доступу",
    "These groups will still be able to receive shares, but not to initiate them." : "Ці групи зможуть отримувати спільні файли, але не зможуть відправляти їх.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Дозволити автоматичне доповнення користувача в діалозі обміну. Якщо вимкнено, потрібно ввести ім'я користувача чи електронну адресу повністю.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Показати текст відмови від відповідальності на сторінці завантаження загальнодоступного посилання. (Показується лише тоді, коли список файлів приховано.)",
    "Default share permissions" : "Дозволи на публікування по замовчуванню",
    "Personal" : "Особисте",
    "Administration" : "Адміністрування",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Розроблено {communityopen}спільнотою Nextcloud{linkclose}, {githubopen}сирцевий код{linkclose} ліцензований під ліцензією {licenseopen}AGPL{linkclose}.",
    "Profile picture" : "Зображення облікового запису",
    "Upload new" : "Завантажити нове",
    "Select from Files" : "Вибрати з файлів",
    "Remove image" : "Видалити зображення",
    "png or jpg, max. 20 MB" : "png або jpg, макс. 20 МБ",
    "Picture provided by original account" : "Картинка надана оригінальним обліковим записом",
    "Cancel" : "Відмінити",
    "Choose as profile picture" : "Обрати як зображення для профілю",
    "Details" : "Деталі",
    "You are a member of the following groups:" : "Ви є членом наступних груп:",
    "You are using <strong>%s</strong>" : "Ви використовуєте <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Ви використовуєте <strong>%1$s</strong> з <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "Повне ім'я",
    "No display name set" : "Ім'я для відображення не вказано",
    "Your email address" : "Ваша адреса електронної пошти",
    "No email address set" : "E-mail не вказано",
    "For password reset and notifications" : "Для скидання пароля та сповіщень",
    "Phone number" : "Номер телефону",
    "Your phone number" : "Ваш номер телефону",
    "Address" : "Адреса",
    "Your postal address" : "Ваша поштова адреса",
    "Website" : "Веб-сайт",
    "It can take up to 24 hours before the account is displayed as verified." : "Підтвердження облікового запису може тривати до 24 годин.",
    "Link https://…" : "Посилання https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Ім'я в Twitter @…",
    "Help translate" : "Допомогти з перекладом",
    "Locale" : "Регіональні станадрти",
    "Current password" : "Поточний пароль",
    "Change password" : "Змінити пароль",
    "Store credentials" : "Зберігати облікові дані"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
